summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/label.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/label.h')
-rw-r--r--kalarm/lib/label.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kalarm/lib/label.h b/kalarm/lib/label.h
index c65a7fcd6..4c0d74216 100644
--- a/kalarm/lib/label.h
+++ b/kalarm/lib/label.h
@@ -21,12 +21,12 @@
#ifndef LABEL_H
#define LABEL_H
-#include <qlabel.h>
+#include <tqlabel.h>
class QRadioButton;
class LabelFocusWidget;
/**
* @short A QLabel with option for a buddy radio button.
*
* The Label class provides a text display, with special behaviour when a radio
* button is set as a buddy.
@@ -34,7 +34,7 @@ class LabelFocusWidget;
* The Label object in effect acts as if it were part of the buddy radio button,
* in that when the label's accelerator key is pressed, the radio button receives
* focus and is switched on. When a non-radio button is specified as a buddy, the
* behaviour is the same as for QLabel.
*
* @author David Jarvie <software@astrojar.org.uk>
*/
@@ -46,16 +46,16 @@ class Label : public QLabel
/** Constructs an empty label.
* @param parent The parent object of this widget.
* @param name The name of this widget.
* @param f Flags. See QWidget constructor for details.
*/
- explicit Label(QWidget* parent, const char* name = 0, WFlags f = 0);
+ explicit Label(TQWidget* parent, const char* name = 0, WFlags f = 0);
/** Constructs a label that displays @p text.
* @param text Text string to display.
* @param parent The parent object of this widget.
* @param name The name of this widget.
* @param f Flags. See QWidget constructor for details.
*/
- Label(const QString& text, QWidget* parent, const char* name = 0, WFlags f = 0);
+ Label(const TQString& text, TQWidget* parent, const char* name = 0, WFlags f = 0);
/** Constructs a label, with a buddy widget, that displays @p text.
* @param buddy Buddy widget which receives the keyboard focus when the
* label's accelerator key is pressed. If @p buddy is a radio
@@ -64,21 +64,21 @@ class Label : public QLabel
* @param text Text string to display.
* @param parent The parent object of this widget.
* @param name The name of this widget.
* @param f Flags. See QWidget constructor for details.
*/
- Label(QWidget* buddy, const QString& text, QWidget* parent, const char* name = 0, WFlags f = 0);
+ Label(TQWidget* buddy, const TQString& text, TQWidget* parent, const char* name = 0, WFlags f = 0);
/** Sets the label's buddy widget which receives the keyboard focus when the
* label's accelerator key is pressed. If @p buddy is a radio button,
* @p buddy is in addition selected when the accelerator key is pressed.
*/
- virtual void setBuddy(QWidget* buddy);
+ virtual void setBuddy(TQWidget* buddy);
protected:
- virtual void drawContents(QPainter* p) { QLabel::drawContents(p); }
+ virtual void drawContents(TQPainter* p) { TQLabel::drawContents(p); }
private slots:
void buddyDead();
private:
void activated();
- QRadioButton* mRadioButton; // buddy widget if it's a radio button, else 0
+ TQRadioButton* mRadioButton; // buddy widget if it's a radio button, else 0
LabelFocusWidget* mFocusWidget;
};
@@ -88,9 +88,9 @@ class LabelFocusWidget : public QWidget
{
Q_OBJECT
public:
- LabelFocusWidget(QWidget* parent, const char* name = 0);
+ LabelFocusWidget(TQWidget* parent, const char* name = 0);
protected:
- virtual void focusInEvent(QFocusEvent*);
+ virtual void focusInEvent(TQFocusEvent*);
};
#endif // LABEL_H
@@ -21,12 +21,12 @@
class LabelFocusWidget;
/**
- * @short A QLabel with option for a buddy radio button.
+ * @short A TQLabel with option for a buddy radio button.
*
* The Label class provides a text display, with special behaviour when a radio
@@ -34,7 +34,7 @@ class LabelFocusWidget;
* in that when the label's accelerator key is pressed, the radio button receives
* focus and is switched on. When a non-radio button is specified as a buddy, the
- * behaviour is the same as for QLabel.
+ * behaviour is the same as for TQLabel.
*
* @author David Jarvie <software@astrojar.org.uk>
@@ -46,16 +46,16 @@ class Label : public QLabel
* @param parent The parent object of this widget.
* @param name The name of this widget.
- * @param f Flags. See QWidget constructor for details.
+ * @param f Flags. See TQWidget constructor for details.
*/
@@ -46,16 +46,16 @@ class Label : public QLabel
* @param parent The parent object of this widget.
* @param name The name of this widget.
- * @param f Flags. See QWidget constructor for details.
+ * @param f Flags. See TQWidget constructor for details.
*/
@@ -64,21 +64,21 @@ class Label : public QLabel
* @param parent The parent object of this widget.
* @param name The name of this widget.
- * @param f Flags. See QWidget constructor for details.
+ * @param f Flags. See TQWidget constructor for details.
*/